# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKImageFilterBasePython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkTernaryGeneratorImageFilterPython
else:
    import _itkTernaryGeneratorImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkImagePython
import itk.itkFixedArrayPython
import itk.pyBasePython
import itk.itkVectorPython
import itk.vnl_vector_refPython
import itk.stdcomplexPython
import itk.vnl_vectorPython
import itk.vnl_matrixPython
import itk.itkPointPython
import itk.itkMatrixPython
import itk.itkCovariantVectorPython
import itk.vnl_matrix_fixedPython
import itk.itkSizePython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkRGBPixelPython
import itk.itkIndexPython
import itk.itkOffsetPython
import itk.itkRGBAPixelPython
import itk.ITKCommonBasePython
import itk.itkImageRegionPython
import itk.itkSimpleDataObjectDecoratorPython
import itk.itkArrayPython
import itk.itkInPlaceImageFilterAPython
import itk.itkImageToImageFilterBPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkImageSourcePython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkImageSourceCommonPython
import itk.itkImageToImageFilterCommonPython
import itk.itkImageToImageFilterAPython

def itkTernaryGeneratorImageFilterIF2IF2IF2IF2_New():
    return itkTernaryGeneratorImageFilterIF2IF2IF2IF2.New()

class itkTernaryGeneratorImageFilterIF2IF2IF2IF2(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIF2IF2):
    r"""Proxy of C++ itkTernaryGeneratorImageFilterIF2IF2IF2IF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkTernaryGeneratorImageFilterIF2IF2IF2IF2_Pointer"""
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIF2IF2IF2IF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkTernaryGeneratorImageFilterIF2IF2IF2IF2_Pointer"""
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIF2IF2IF2IF2_Clone(self)

    def SetInput1(self, *args):
        r"""
        SetInput1(self, image1)

        Parameters
        ----------
        image1: itkImageF2 const *

        SetInput1(self, input1)

        Parameters
        ----------
        input1: itkSimpleDataObjectDecoratorF const *

        SetInput1(self, input1)

        Parameters
        ----------
        input1: float const &

        """
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIF2IF2IF2IF2_SetInput1(self, *args)

    def SetConstant1(self, input1):
        r"""
        SetConstant1(self, input1)

        Parameters
        ----------
        input1: float const &

        """
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIF2IF2IF2IF2_SetConstant1(self, input1)

    def GetConstant1(self):
        r"""GetConstant1(self) -> float const &"""
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIF2IF2IF2IF2_GetConstant1(self)

    def SetInput2(self, *args):
        r"""
        SetInput2(self, image2)

        Parameters
        ----------
        image2: itkImageF2 const *

        SetInput2(self, input2)

        Parameters
        ----------
        input2: itkSimpleDataObjectDecoratorF const *

        SetInput2(self, input2)

        Parameters
        ----------
        input2: float const &

        """
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIF2IF2IF2IF2_SetInput2(self, *args)

    def SetConstant2(self, input2):
        r"""
        SetConstant2(self, input2)

        Parameters
        ----------
        input2: float const &

        """
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIF2IF2IF2IF2_SetConstant2(self, input2)

    def GetConstant2(self):
        r"""GetConstant2(self) -> float const &"""
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIF2IF2IF2IF2_GetConstant2(self)

    def SetInput3(self, *args):
        r"""
        SetInput3(self, image3)

        Parameters
        ----------
        image3: itkImageF2 const *

        SetInput3(self, input3)

        Parameters
        ----------
        input3: itkSimpleDataObjectDecoratorF const *

        SetInput3(self, input3)

        Parameters
        ----------
        input3: float const &

        """
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIF2IF2IF2IF2_SetInput3(self, *args)

    def SetConstant3(self, input3):
        r"""
        SetConstant3(self, input3)

        Parameters
        ----------
        input3: float const &

        """
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIF2IF2IF2IF2_SetConstant3(self, input3)

    def GetConstant3(self):
        r"""GetConstant3(self) -> float const &"""
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIF2IF2IF2IF2_GetConstant3(self)
    SameDimensionCheck1 = _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIF2IF2IF2IF2_SameDimensionCheck1
    
    SameDimensionCheck2 = _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIF2IF2IF2IF2_SameDimensionCheck2
    
    SameDimensionCheck3 = _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIF2IF2IF2IF2_SameDimensionCheck3
    
    __swig_destroy__ = _itkTernaryGeneratorImageFilterPython.delete_itkTernaryGeneratorImageFilterIF2IF2IF2IF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkTernaryGeneratorImageFilterIF2IF2IF2IF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIF2IF2IF2IF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkTernaryGeneratorImageFilterIF2IF2IF2IF2

        Create a new object of the class itkTernaryGeneratorImageFilterIF2IF2IF2IF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkTernaryGeneratorImageFilterIF2IF2IF2IF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkTernaryGeneratorImageFilterIF2IF2IF2IF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkTernaryGeneratorImageFilterIF2IF2IF2IF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkTernaryGeneratorImageFilterIF2IF2IF2IF2 in _itkTernaryGeneratorImageFilterPython:
_itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIF2IF2IF2IF2_swigregister(itkTernaryGeneratorImageFilterIF2IF2IF2IF2)

def itkTernaryGeneratorImageFilterIF3IF3IF3IF3_New():
    return itkTernaryGeneratorImageFilterIF3IF3IF3IF3.New()

class itkTernaryGeneratorImageFilterIF3IF3IF3IF3(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIF3IF3):
    r"""Proxy of C++ itkTernaryGeneratorImageFilterIF3IF3IF3IF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkTernaryGeneratorImageFilterIF3IF3IF3IF3_Pointer"""
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIF3IF3IF3IF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkTernaryGeneratorImageFilterIF3IF3IF3IF3_Pointer"""
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIF3IF3IF3IF3_Clone(self)

    def SetInput1(self, *args):
        r"""
        SetInput1(self, image1)

        Parameters
        ----------
        image1: itkImageF3 const *

        SetInput1(self, input1)

        Parameters
        ----------
        input1: itkSimpleDataObjectDecoratorF const *

        SetInput1(self, input1)

        Parameters
        ----------
        input1: float const &

        """
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIF3IF3IF3IF3_SetInput1(self, *args)

    def SetConstant1(self, input1):
        r"""
        SetConstant1(self, input1)

        Parameters
        ----------
        input1: float const &

        """
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIF3IF3IF3IF3_SetConstant1(self, input1)

    def GetConstant1(self):
        r"""GetConstant1(self) -> float const &"""
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIF3IF3IF3IF3_GetConstant1(self)

    def SetInput2(self, *args):
        r"""
        SetInput2(self, image2)

        Parameters
        ----------
        image2: itkImageF3 const *

        SetInput2(self, input2)

        Parameters
        ----------
        input2: itkSimpleDataObjectDecoratorF const *

        SetInput2(self, input2)

        Parameters
        ----------
        input2: float const &

        """
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIF3IF3IF3IF3_SetInput2(self, *args)

    def SetConstant2(self, input2):
        r"""
        SetConstant2(self, input2)

        Parameters
        ----------
        input2: float const &

        """
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIF3IF3IF3IF3_SetConstant2(self, input2)

    def GetConstant2(self):
        r"""GetConstant2(self) -> float const &"""
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIF3IF3IF3IF3_GetConstant2(self)

    def SetInput3(self, *args):
        r"""
        SetInput3(self, image3)

        Parameters
        ----------
        image3: itkImageF3 const *

        SetInput3(self, input3)

        Parameters
        ----------
        input3: itkSimpleDataObjectDecoratorF const *

        SetInput3(self, input3)

        Parameters
        ----------
        input3: float const &

        """
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIF3IF3IF3IF3_SetInput3(self, *args)

    def SetConstant3(self, input3):
        r"""
        SetConstant3(self, input3)

        Parameters
        ----------
        input3: float const &

        """
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIF3IF3IF3IF3_SetConstant3(self, input3)

    def GetConstant3(self):
        r"""GetConstant3(self) -> float const &"""
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIF3IF3IF3IF3_GetConstant3(self)
    SameDimensionCheck1 = _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIF3IF3IF3IF3_SameDimensionCheck1
    
    SameDimensionCheck2 = _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIF3IF3IF3IF3_SameDimensionCheck2
    
    SameDimensionCheck3 = _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIF3IF3IF3IF3_SameDimensionCheck3
    
    __swig_destroy__ = _itkTernaryGeneratorImageFilterPython.delete_itkTernaryGeneratorImageFilterIF3IF3IF3IF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkTernaryGeneratorImageFilterIF3IF3IF3IF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIF3IF3IF3IF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkTernaryGeneratorImageFilterIF3IF3IF3IF3

        Create a new object of the class itkTernaryGeneratorImageFilterIF3IF3IF3IF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkTernaryGeneratorImageFilterIF3IF3IF3IF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkTernaryGeneratorImageFilterIF3IF3IF3IF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkTernaryGeneratorImageFilterIF3IF3IF3IF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkTernaryGeneratorImageFilterIF3IF3IF3IF3 in _itkTernaryGeneratorImageFilterPython:
_itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIF3IF3IF3IF3_swigregister(itkTernaryGeneratorImageFilterIF3IF3IF3IF3)

def itkTernaryGeneratorImageFilterISS2ISS2ISS2ISS2_New():
    return itkTernaryGeneratorImageFilterISS2ISS2ISS2ISS2.New()

class itkTernaryGeneratorImageFilterISS2ISS2ISS2ISS2(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterISS2ISS2):
    r"""Proxy of C++ itkTernaryGeneratorImageFilterISS2ISS2ISS2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkTernaryGeneratorImageFilterISS2ISS2ISS2ISS2_Pointer"""
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterISS2ISS2ISS2ISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkTernaryGeneratorImageFilterISS2ISS2ISS2ISS2_Pointer"""
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterISS2ISS2ISS2ISS2_Clone(self)

    def SetInput1(self, *args):
        r"""
        SetInput1(self, image1)

        Parameters
        ----------
        image1: itkImageSS2 const *

        SetInput1(self, input1)

        Parameters
        ----------
        input1: itkSimpleDataObjectDecoratorSS const *

        SetInput1(self, input1)

        Parameters
        ----------
        input1: short const &

        """
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterISS2ISS2ISS2ISS2_SetInput1(self, *args)

    def SetConstant1(self, input1):
        r"""
        SetConstant1(self, input1)

        Parameters
        ----------
        input1: short const &

        """
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterISS2ISS2ISS2ISS2_SetConstant1(self, input1)

    def GetConstant1(self):
        r"""GetConstant1(self) -> short const &"""
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterISS2ISS2ISS2ISS2_GetConstant1(self)

    def SetInput2(self, *args):
        r"""
        SetInput2(self, image2)

        Parameters
        ----------
        image2: itkImageSS2 const *

        SetInput2(self, input2)

        Parameters
        ----------
        input2: itkSimpleDataObjectDecoratorSS const *

        SetInput2(self, input2)

        Parameters
        ----------
        input2: short const &

        """
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterISS2ISS2ISS2ISS2_SetInput2(self, *args)

    def SetConstant2(self, input2):
        r"""
        SetConstant2(self, input2)

        Parameters
        ----------
        input2: short const &

        """
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterISS2ISS2ISS2ISS2_SetConstant2(self, input2)

    def GetConstant2(self):
        r"""GetConstant2(self) -> short const &"""
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterISS2ISS2ISS2ISS2_GetConstant2(self)

    def SetInput3(self, *args):
        r"""
        SetInput3(self, image3)

        Parameters
        ----------
        image3: itkImageSS2 const *

        SetInput3(self, input3)

        Parameters
        ----------
        input3: itkSimpleDataObjectDecoratorSS const *

        SetInput3(self, input3)

        Parameters
        ----------
        input3: short const &

        """
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterISS2ISS2ISS2ISS2_SetInput3(self, *args)

    def SetConstant3(self, input3):
        r"""
        SetConstant3(self, input3)

        Parameters
        ----------
        input3: short const &

        """
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterISS2ISS2ISS2ISS2_SetConstant3(self, input3)

    def GetConstant3(self):
        r"""GetConstant3(self) -> short const &"""
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterISS2ISS2ISS2ISS2_GetConstant3(self)
    SameDimensionCheck1 = _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterISS2ISS2ISS2ISS2_SameDimensionCheck1
    
    SameDimensionCheck2 = _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterISS2ISS2ISS2ISS2_SameDimensionCheck2
    
    SameDimensionCheck3 = _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterISS2ISS2ISS2ISS2_SameDimensionCheck3
    
    __swig_destroy__ = _itkTernaryGeneratorImageFilterPython.delete_itkTernaryGeneratorImageFilterISS2ISS2ISS2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkTernaryGeneratorImageFilterISS2ISS2ISS2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterISS2ISS2ISS2ISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkTernaryGeneratorImageFilterISS2ISS2ISS2ISS2

        Create a new object of the class itkTernaryGeneratorImageFilterISS2ISS2ISS2ISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkTernaryGeneratorImageFilterISS2ISS2ISS2ISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkTernaryGeneratorImageFilterISS2ISS2ISS2ISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkTernaryGeneratorImageFilterISS2ISS2ISS2ISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkTernaryGeneratorImageFilterISS2ISS2ISS2ISS2 in _itkTernaryGeneratorImageFilterPython:
_itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterISS2ISS2ISS2ISS2_swigregister(itkTernaryGeneratorImageFilterISS2ISS2ISS2ISS2)

def itkTernaryGeneratorImageFilterISS3ISS3ISS3ISS3_New():
    return itkTernaryGeneratorImageFilterISS3ISS3ISS3ISS3.New()

class itkTernaryGeneratorImageFilterISS3ISS3ISS3ISS3(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterISS3ISS3):
    r"""Proxy of C++ itkTernaryGeneratorImageFilterISS3ISS3ISS3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkTernaryGeneratorImageFilterISS3ISS3ISS3ISS3_Pointer"""
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterISS3ISS3ISS3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkTernaryGeneratorImageFilterISS3ISS3ISS3ISS3_Pointer"""
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterISS3ISS3ISS3ISS3_Clone(self)

    def SetInput1(self, *args):
        r"""
        SetInput1(self, image1)

        Parameters
        ----------
        image1: itkImageSS3 const *

        SetInput1(self, input1)

        Parameters
        ----------
        input1: itkSimpleDataObjectDecoratorSS const *

        SetInput1(self, input1)

        Parameters
        ----------
        input1: short const &

        """
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterISS3ISS3ISS3ISS3_SetInput1(self, *args)

    def SetConstant1(self, input1):
        r"""
        SetConstant1(self, input1)

        Parameters
        ----------
        input1: short const &

        """
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterISS3ISS3ISS3ISS3_SetConstant1(self, input1)

    def GetConstant1(self):
        r"""GetConstant1(self) -> short const &"""
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterISS3ISS3ISS3ISS3_GetConstant1(self)

    def SetInput2(self, *args):
        r"""
        SetInput2(self, image2)

        Parameters
        ----------
        image2: itkImageSS3 const *

        SetInput2(self, input2)

        Parameters
        ----------
        input2: itkSimpleDataObjectDecoratorSS const *

        SetInput2(self, input2)

        Parameters
        ----------
        input2: short const &

        """
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterISS3ISS3ISS3ISS3_SetInput2(self, *args)

    def SetConstant2(self, input2):
        r"""
        SetConstant2(self, input2)

        Parameters
        ----------
        input2: short const &

        """
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterISS3ISS3ISS3ISS3_SetConstant2(self, input2)

    def GetConstant2(self):
        r"""GetConstant2(self) -> short const &"""
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterISS3ISS3ISS3ISS3_GetConstant2(self)

    def SetInput3(self, *args):
        r"""
        SetInput3(self, image3)

        Parameters
        ----------
        image3: itkImageSS3 const *

        SetInput3(self, input3)

        Parameters
        ----------
        input3: itkSimpleDataObjectDecoratorSS const *

        SetInput3(self, input3)

        Parameters
        ----------
        input3: short const &

        """
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterISS3ISS3ISS3ISS3_SetInput3(self, *args)

    def SetConstant3(self, input3):
        r"""
        SetConstant3(self, input3)

        Parameters
        ----------
        input3: short const &

        """
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterISS3ISS3ISS3ISS3_SetConstant3(self, input3)

    def GetConstant3(self):
        r"""GetConstant3(self) -> short const &"""
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterISS3ISS3ISS3ISS3_GetConstant3(self)
    SameDimensionCheck1 = _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterISS3ISS3ISS3ISS3_SameDimensionCheck1
    
    SameDimensionCheck2 = _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterISS3ISS3ISS3ISS3_SameDimensionCheck2
    
    SameDimensionCheck3 = _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterISS3ISS3ISS3ISS3_SameDimensionCheck3
    
    __swig_destroy__ = _itkTernaryGeneratorImageFilterPython.delete_itkTernaryGeneratorImageFilterISS3ISS3ISS3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkTernaryGeneratorImageFilterISS3ISS3ISS3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterISS3ISS3ISS3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkTernaryGeneratorImageFilterISS3ISS3ISS3ISS3

        Create a new object of the class itkTernaryGeneratorImageFilterISS3ISS3ISS3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkTernaryGeneratorImageFilterISS3ISS3ISS3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkTernaryGeneratorImageFilterISS3ISS3ISS3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkTernaryGeneratorImageFilterISS3ISS3ISS3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkTernaryGeneratorImageFilterISS3ISS3ISS3ISS3 in _itkTernaryGeneratorImageFilterPython:
_itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterISS3ISS3ISS3ISS3_swigregister(itkTernaryGeneratorImageFilterISS3ISS3ISS3ISS3)

def itkTernaryGeneratorImageFilterIUC2IUC2IUC2IUC2_New():
    return itkTernaryGeneratorImageFilterIUC2IUC2IUC2IUC2.New()

class itkTernaryGeneratorImageFilterIUC2IUC2IUC2IUC2(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIUC2IUC2):
    r"""Proxy of C++ itkTernaryGeneratorImageFilterIUC2IUC2IUC2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkTernaryGeneratorImageFilterIUC2IUC2IUC2IUC2_Pointer"""
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIUC2IUC2IUC2IUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkTernaryGeneratorImageFilterIUC2IUC2IUC2IUC2_Pointer"""
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIUC2IUC2IUC2IUC2_Clone(self)

    def SetInput1(self, *args):
        r"""
        SetInput1(self, image1)

        Parameters
        ----------
        image1: itkImageUC2 const *

        SetInput1(self, input1)

        Parameters
        ----------
        input1: itkSimpleDataObjectDecoratorUC const *

        SetInput1(self, input1)

        Parameters
        ----------
        input1: unsigned char const &

        """
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIUC2IUC2IUC2IUC2_SetInput1(self, *args)

    def SetConstant1(self, input1):
        r"""
        SetConstant1(self, input1)

        Parameters
        ----------
        input1: unsigned char const &

        """
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIUC2IUC2IUC2IUC2_SetConstant1(self, input1)

    def GetConstant1(self):
        r"""GetConstant1(self) -> unsigned char const &"""
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIUC2IUC2IUC2IUC2_GetConstant1(self)

    def SetInput2(self, *args):
        r"""
        SetInput2(self, image2)

        Parameters
        ----------
        image2: itkImageUC2 const *

        SetInput2(self, input2)

        Parameters
        ----------
        input2: itkSimpleDataObjectDecoratorUC const *

        SetInput2(self, input2)

        Parameters
        ----------
        input2: unsigned char const &

        """
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIUC2IUC2IUC2IUC2_SetInput2(self, *args)

    def SetConstant2(self, input2):
        r"""
        SetConstant2(self, input2)

        Parameters
        ----------
        input2: unsigned char const &

        """
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIUC2IUC2IUC2IUC2_SetConstant2(self, input2)

    def GetConstant2(self):
        r"""GetConstant2(self) -> unsigned char const &"""
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIUC2IUC2IUC2IUC2_GetConstant2(self)

    def SetInput3(self, *args):
        r"""
        SetInput3(self, image3)

        Parameters
        ----------
        image3: itkImageUC2 const *

        SetInput3(self, input3)

        Parameters
        ----------
        input3: itkSimpleDataObjectDecoratorUC const *

        SetInput3(self, input3)

        Parameters
        ----------
        input3: unsigned char const &

        """
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIUC2IUC2IUC2IUC2_SetInput3(self, *args)

    def SetConstant3(self, input3):
        r"""
        SetConstant3(self, input3)

        Parameters
        ----------
        input3: unsigned char const &

        """
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIUC2IUC2IUC2IUC2_SetConstant3(self, input3)

    def GetConstant3(self):
        r"""GetConstant3(self) -> unsigned char const &"""
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIUC2IUC2IUC2IUC2_GetConstant3(self)
    SameDimensionCheck1 = _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIUC2IUC2IUC2IUC2_SameDimensionCheck1
    
    SameDimensionCheck2 = _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIUC2IUC2IUC2IUC2_SameDimensionCheck2
    
    SameDimensionCheck3 = _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIUC2IUC2IUC2IUC2_SameDimensionCheck3
    
    __swig_destroy__ = _itkTernaryGeneratorImageFilterPython.delete_itkTernaryGeneratorImageFilterIUC2IUC2IUC2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkTernaryGeneratorImageFilterIUC2IUC2IUC2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIUC2IUC2IUC2IUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkTernaryGeneratorImageFilterIUC2IUC2IUC2IUC2

        Create a new object of the class itkTernaryGeneratorImageFilterIUC2IUC2IUC2IUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkTernaryGeneratorImageFilterIUC2IUC2IUC2IUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkTernaryGeneratorImageFilterIUC2IUC2IUC2IUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkTernaryGeneratorImageFilterIUC2IUC2IUC2IUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkTernaryGeneratorImageFilterIUC2IUC2IUC2IUC2 in _itkTernaryGeneratorImageFilterPython:
_itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIUC2IUC2IUC2IUC2_swigregister(itkTernaryGeneratorImageFilterIUC2IUC2IUC2IUC2)

def itkTernaryGeneratorImageFilterIUC3IUC3IUC3IUC3_New():
    return itkTernaryGeneratorImageFilterIUC3IUC3IUC3IUC3.New()

class itkTernaryGeneratorImageFilterIUC3IUC3IUC3IUC3(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIUC3IUC3):
    r"""Proxy of C++ itkTernaryGeneratorImageFilterIUC3IUC3IUC3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkTernaryGeneratorImageFilterIUC3IUC3IUC3IUC3_Pointer"""
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIUC3IUC3IUC3IUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkTernaryGeneratorImageFilterIUC3IUC3IUC3IUC3_Pointer"""
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIUC3IUC3IUC3IUC3_Clone(self)

    def SetInput1(self, *args):
        r"""
        SetInput1(self, image1)

        Parameters
        ----------
        image1: itkImageUC3 const *

        SetInput1(self, input1)

        Parameters
        ----------
        input1: itkSimpleDataObjectDecoratorUC const *

        SetInput1(self, input1)

        Parameters
        ----------
        input1: unsigned char const &

        """
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIUC3IUC3IUC3IUC3_SetInput1(self, *args)

    def SetConstant1(self, input1):
        r"""
        SetConstant1(self, input1)

        Parameters
        ----------
        input1: unsigned char const &

        """
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIUC3IUC3IUC3IUC3_SetConstant1(self, input1)

    def GetConstant1(self):
        r"""GetConstant1(self) -> unsigned char const &"""
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIUC3IUC3IUC3IUC3_GetConstant1(self)

    def SetInput2(self, *args):
        r"""
        SetInput2(self, image2)

        Parameters
        ----------
        image2: itkImageUC3 const *

        SetInput2(self, input2)

        Parameters
        ----------
        input2: itkSimpleDataObjectDecoratorUC const *

        SetInput2(self, input2)

        Parameters
        ----------
        input2: unsigned char const &

        """
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIUC3IUC3IUC3IUC3_SetInput2(self, *args)

    def SetConstant2(self, input2):
        r"""
        SetConstant2(self, input2)

        Parameters
        ----------
        input2: unsigned char const &

        """
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIUC3IUC3IUC3IUC3_SetConstant2(self, input2)

    def GetConstant2(self):
        r"""GetConstant2(self) -> unsigned char const &"""
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIUC3IUC3IUC3IUC3_GetConstant2(self)

    def SetInput3(self, *args):
        r"""
        SetInput3(self, image3)

        Parameters
        ----------
        image3: itkImageUC3 const *

        SetInput3(self, input3)

        Parameters
        ----------
        input3: itkSimpleDataObjectDecoratorUC const *

        SetInput3(self, input3)

        Parameters
        ----------
        input3: unsigned char const &

        """
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIUC3IUC3IUC3IUC3_SetInput3(self, *args)

    def SetConstant3(self, input3):
        r"""
        SetConstant3(self, input3)

        Parameters
        ----------
        input3: unsigned char const &

        """
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIUC3IUC3IUC3IUC3_SetConstant3(self, input3)

    def GetConstant3(self):
        r"""GetConstant3(self) -> unsigned char const &"""
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIUC3IUC3IUC3IUC3_GetConstant3(self)
    SameDimensionCheck1 = _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIUC3IUC3IUC3IUC3_SameDimensionCheck1
    
    SameDimensionCheck2 = _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIUC3IUC3IUC3IUC3_SameDimensionCheck2
    
    SameDimensionCheck3 = _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIUC3IUC3IUC3IUC3_SameDimensionCheck3
    
    __swig_destroy__ = _itkTernaryGeneratorImageFilterPython.delete_itkTernaryGeneratorImageFilterIUC3IUC3IUC3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkTernaryGeneratorImageFilterIUC3IUC3IUC3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIUC3IUC3IUC3IUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkTernaryGeneratorImageFilterIUC3IUC3IUC3IUC3

        Create a new object of the class itkTernaryGeneratorImageFilterIUC3IUC3IUC3IUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkTernaryGeneratorImageFilterIUC3IUC3IUC3IUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkTernaryGeneratorImageFilterIUC3IUC3IUC3IUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkTernaryGeneratorImageFilterIUC3IUC3IUC3IUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkTernaryGeneratorImageFilterIUC3IUC3IUC3IUC3 in _itkTernaryGeneratorImageFilterPython:
_itkTernaryGeneratorImageFilterPython.itkTernaryGeneratorImageFilterIUC3IUC3IUC3IUC3_swigregister(itkTernaryGeneratorImageFilterIUC3IUC3IUC3IUC3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def ternary_generator_image_filter(*args: itkt.ImageLike,  constant1: int=..., constant2: int=..., constant3: int=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for TernaryGeneratorImageFilter"""
    import itk

    kwarg_typehints = { 'constant1':constant1,'constant2':constant2,'constant3':constant3 }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.TernaryGeneratorImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def ternary_generator_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKImageFilterBase.TernaryGeneratorImageFilter
    ternary_generator_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    ternary_generator_image_filter.__doc__ = filter_object.__doc__



